#ifndef __ZAPPINFOAREA_H__
#define __ZAPPINFOAREA_H__

#include <zwidget.h>

class ZFmwArea;
class ZFmwItem;

// sizeof == sizeof(ZWidget) + 4
class ZAppInfoArea : public ZWidget {
  Q_OBJECT
  public:
    enum AREA_IDX {
      INPUT, ACTIVITY, COUNTER, STORAGE, AREA_NUM    
    };

    enum COUNTERICON_ALIGN {
      LEFT, RIGHT, INVALID_ALIGN
    };

    enum ACTIVITY_MODE {
      PROGRESS_METER, NO_PROGRESS_METER
    };

    enum COUNTER_MODE {
      TWO_VARIABLE_QUALIFIER, ONE_VARIABLE_QUALIFIER, ONE_VARIABLE, FREE
    };

    enum METER_STYLE {
      METER_A, METER_B
    };
    
    enum COUNTER_V {
      LEFT_V, RIGHT_V
    };
    
    ZAppInfoArea(QWidget*, char const*, unsigned int, ZSkinService::WidgetClsID = ZSkinService::clsZAppInfoArea);
    virtual ~ZAppInfoArea();

  protected:
    virtual void paintEvent(QPaintEvent*);
    virtual void setPalette(QPalette const&);
    virtual QSize sizeHint() const;
    
    void getTotalItemNum();
    void getActMeter();
    void setActArea(ZAppInfoArea::ACTIVITY_MODE);
    void setInputArea();
    void isValidArea(ZAppInfoArea::AREA_IDX);
    void isAreaCouldInsertItem(ZAppInfoArea::AREA_IDX);
    void setCounterIcon(ZAppInfoArea::COUNTERICON_ALIGN, QString const&, QPixmap const&);
    void getWidgetRect();
    void getInternalSpacing() const;
    void getSpacing() const;
    void getOutlineColor() const;
    void getAreaWidth(ZFmwArea*) const;
    void getInitAreaWidth(ZFmwArea*);
    void getPadding(int) const;
    void getRect();
    void getAreaWidthExceptStorage();
    void isRemoveNewWordFromInput(ZAppInfoArea::AREA_IDX, ZFmwItem*);
    void isRemoveIconFromArea(ZAppInfoArea::AREA_IDX, ZFmwItem*);
    void removeIconFromArea(ZAppInfoArea::AREA_IDX, int&, bool (ZAppInfoArea::*)(ZAppInfoArea::AREA_IDX, ZFmwItem*));
    void truncateTextFromArea(ZAppInfoArea::AREA_IDX, int&);
    void cropWidgetFromArea(ZAppInfoArea::AREA_IDX, int&);
    void deleteArea(ZAppInfoArea::AREA_IDX, int&);
    void getItemHeight(ZFmwItem*) const;
    void getAreaHeight(ZFmwArea*) const;
    void getContentHeight() const;
    void getWidgetHeight() const;
    void setWidget(ZAppInfoArea::AREA_IDX, int, QWidget*);
    void appendWidget(ZAppInfoArea::AREA_IDX, QWidget*, QString const&);
    void appendAnimation(ZAppInfoArea::AREA_IDX, QString const&, QString const&);
    void insertWidget(ZAppInfoArea::AREA_IDX, int, QWidget*, QString const&);
    void insertAnimation(ZAppInfoArea::AREA_IDX, int, QString const&, QString const&);
    void setWidget(ZAppInfoArea::AREA_IDX, QString const&, QWidget*);
    void setText(ZAppInfoArea::AREA_IDX, QString const&, QString const&);
    void setIcon(ZAppInfoArea::AREA_IDX, QString const&, QPixmap const&);
    void setIcon(ZAppInfoArea::AREA_IDX, QString const&, QString const&);
    void setText(ZAppInfoArea::AREA_IDX, int, QString const&);
    void setIcon(ZAppInfoArea::AREA_IDX, int, QPixmap const&);
    void setIcon(ZAppInfoArea::AREA_IDX, int, QString const&);
    void removeItem(ZAppInfoArea::AREA_IDX, QString const&);
    void removeItem(ZAppInfoArea::AREA_IDX, int);
    void appendIcon(ZAppInfoArea::AREA_IDX, QString const&, QPixmap const&, QString const&);
    void appendIcon(ZAppInfoArea::AREA_IDX, QPixmap const&, QString const&);
    void appendIcon(ZAppInfoArea::AREA_IDX, QString const&, QString const&);
    void appendText(ZAppInfoArea::AREA_IDX, QString const&, QString const&);
    void insertIcon(ZAppInfoArea::AREA_IDX, int, QPixmap const&, QString const&);
    void insertIcon(ZAppInfoArea::AREA_IDX, int, QString const&, QString const&);
    void insertText(ZAppInfoArea::AREA_IDX, int, QString const&, QString const&);
    void setCounterQualifier(QString const&);
    void setCounterVariable(ZAppInfoArea::COUNTER_V, QString const&);
    void removeCounterIcon();
    void setCounterIcon(ZAppInfoArea::COUNTERICON_ALIGN, QPixmap const&);
    void setCounterIcon(ZAppInfoArea::COUNTERICON_ALIGN, QString const&);
    void setCounterArea(ZAppInfoArea::COUNTER_MODE);
    void setStorageIcon(QPixmap const&);
    void setStorageIcon(QString const&);
    void removeArea(ZAppInfoArea::AREA_IDX);
    void setMeterStyle(ZAppInfoArea::METER_STYLE);
    void getMeterStyle();
    void getWidth(ZAppInfoArea::AREA_IDX);
    void printArea(ZAppInfoArea::AREA_IDX);

  /* 'hidden' slots, use for connect only:
   * slotHideIconOfInputArea(int)
   * itemNum(int)
   * */

  private:
    char _zappinfoarea_stuff[4];
};

#endif
