#ifndef __ZAPPLICATION_H__
#define __ZAPPLICATION_H__

#include <quuid.h>
#include <qapplication.h>

class ZWidget;

// sizeof == 0x3c
class ZApplication : public QApplication {
  Q_OBJECT
  public:
    ZApplication(int&, char**, QApplication::Type = GuiClient);
    virtual ~ZApplication();
    int exec();
    
  protected:
    virtual bool eventFilter(QObject*, QEvent*);
    virtual void timerEvent(QTimerEvent*);
    virtual bool notify(QObject*, QEvent*);
    virtual bool qwsEventFilter(QWSEvent*);
    virtual void tryQuit();

  protected slots:
    virtual void slotShutdown();
    virtual void slotQuickQuit();
    virtual void slotUsbStorageInOut(bool);
    virtual void slotClickAppIcon();
    virtual void slotRaise();
    virtual void slotLanguageChange();
    virtual void slotThemeChange();
    virtual void slotReturnToIdle(int);
    virtual void slotLaunchactionByIdlescreen(const QUuid&);
    virtual void slotLaunchactionByMainscreen(const QUuid&);
    virtual void slotLaunchactionByVoicecommand(const QUuid&);
    virtual void slotLaunchactionByDedicatedkey(const QUuid&);
    virtual void slotLaunchactionByAnotherApp(const QUuid&);
    virtual void slotKillactionByMassstorage();

  /* 'hidden' slots:
   * animationTimeOut()
   * animationStatus(int)
   * animationUpdate(const QRect&)
   * slotCursorSelected(QWSCursor*)
   * slotSysSetupMessage(const QCString&,const QByteArray&)
   * slotSystemMessage(const QCString&,const QByteArray&)
   * slotServerMessage(const QCString&,const QByteArray&)
   * slotAppMessage(const QCString&,const QByteArray&)
   * pidMessage(const QCString&,const QByteArray&)
   * resetMouseMode()
   * resetPressHoldStatus()
   * slotKbStateChanged(const QRect&,int,bool,bool)
   * slotHKData(QCString&, const QByteArray&)
   * */
  
  protected:
    const QString &getAppName();
    void startShowWaitCursor(int, QString const&);
    void stopShowWaitCursor();
    void getDefaultKbMethod(bool);
    void getTouchSoundMsgQueue();
    void updateIMNameList();
    void setAutoInvokeKb(bool);
    void getAutoInvokeKb();
    void getAutoHideKb();
    void loadString(QString const&);
    void getKBState();
    void setAutoInvokeKb(QWidget*, bool);
    void getKbInputField(QWidget*);
    void registerEditableWidget(char const*);
    void setInputMethods(QWidget*, QUuid const&, QValueList<QUuid> const&, int, QString);
    void getSkinnableProperties();
    void setAppFSBA(QPixmap const&, int, int);
    void getFSBAImage(int);
    void getAppSysFSBAID();
    void getSkinService(ZWidget const*) const;
    void getFSBA(ZWidget const*);
    const char *getAppChannel();
    void getAppLayoutDirection() const;
    void raiseAppWindows();
    void getAppChannelName();
    void flushMsgs();
    void getMouseMode(QWidget*);
    void setMouseMode(QWidget*, int);
    void askDialogsDismiss(int);
    void setInputMethod(QWidget*, QUuid const&, int, QString);
    void getIMList();
  
  signals:
    void appMessage(const QCString&,const QByteArray&);
    void shutdown();
    void quickQuick();
    void usbStorageInOut(bool);
    void signalRaise();
    void signalRaiseWithPolicy(int);
    void clickAppIcon();
    void signalLanguageChange();
    void signalAppThemeChange();
    void signalThemeChange();
    void signalAppLaunched(const QUuid);
    void signalAppKilled(const QUuid);
    void signalOpenDoc(const QString&);
    void signalCmdLine(const QString&);
    void signalBridgeMessage(const QByteArray&);
    void signalBridgeMessage(const QCString&, const QByteArray&);
    void signalBridgeMessageWithoutRaise(const QCString&,const QByteArray&);
    void signalMasterClear();
    void signalTcmdMasterClear();
    void signalMasterReset();
    void signalTcmdMasterReset();
    void signalLaunchactionByIdlescreen(const QUuid&);
    void signalLaunchactionByMainscreen(const QUuid&);
    void signalLaunchactionByVoicecommand(const QUuid&);
    void signalLaunchactionByDedicatedkey(const QUuid&);
    void signalLaunchactionByAnotherApp(const QUuid&);
    void signalKillactionByMassstorage();
    void systemMessage(const QCString&, const QByteArray&);
    void processMessage(const QCString&, const QByteArray&);
    void flipStatusChanged(int);
    void sliderStatusChanged(int);
    void signalKbStateChanged(const QRect&,int,bool,bool);
    void kbStateChanged(bool, const QUuid&, int);
    void askReturnToIdle(int);
    void mainWidgetSizeChanged(int, const QRect&);
  
  private:
    char _zapplication_stuff[60 - sizeof(QApplication)];
};

#endif
