#ifndef __ZHEADER_H__
#define __ZHEADER_H__

#include <zwidget.h>

// sizeof == sizeof(ZWidget) + 4
class ZHeader : public ZWidget {
  Q_OBJECT
  public:
    enum HEADER_TYPE {
      CLI_HEADER, CLI_IDL, MAINDISPLAY_IDL, MAINDISPLAY_HEADER, HEADER_TYPE_NUM
    };

    enum HEADER_STATUS {
      AIRPLANE = 1, ROAMING, SIGNAL, ACTIVE_CIRCUIT_DATA_CALL, ACTIVE_VOICE_CALL,
      VIDEO_CALL, UMA, WIFI, GPRS, EDGE, THREEG, CDMAPDS, SERVICE, CALLFORWARDING,
      ACTIVELINE, VOICEPRIVACY, VR, BATTERY, IM, SYNC, BT, NOTIFY, PRESENCE,
      LOCATION, HOMEZONE, ALERT, WIFISIGNAL, USB, SPEAKER, FDN, HSDPA, JAVA,
      PTT, ROGERSMAIL, VIDEO_MAIL, VOICE_MAIL, EMAIL, VIDEO_MESSAGE, VOICE_MESSAGE,
      TEXT_MESSAGE, MESSAGE, MULTIMEDIA, RADIO, DLNA, STATUS_NUM
    };

    // sizeof at least == 0xc + 4
    // last 4 is a pointer
    struct AppStatusInfo_S {
      AppStatusInfo_S();
      ~AppStatusInfo_S();

      private:
        char _appstatusinfos_stuff[0xc + 4];
    };

    ZHeader(ZHeader::HEADER_TYPE, QWidget*, char const*, unsigned int);
    ZHeader(QWidget*, char const*, unsigned int);
    virtual ~ZHeader();
    
    // return QCopChannel::send("headerregister", "register()", data)
    // if channel exists, otherwise false (QCopChannel::isRegistered)
    // seems to be static
    static bool registerInfo(ZHeader::AppStatusInfo_S const& data);

    // return QCopChannel::send("headerregister", "unregister()", data)
    // if channel exists, otherwise false (QCopChannel::isRegistered)
    // seems to be static
    static bool unregisterInfo(ZHeader::HEADER_STATUS data);
    
    virtual void setPalette(QPalette const&);
    virtual void paintEvent(QPaintEvent*);
    virtual void resizeEvent(QResizeEvent*);
    
    bool isTruncEnable();
    void setTruncEnable(bool);

  protected:
    void getPrimTitle();
    void getSecondTitle();
    void getTitleIcon();
    void setPrimTitle(QString const&);
    void setSecondTitle(QString const&);
    void switchHeader(ZHeader::HEADER_TYPE);
    void changeStatus(ZHeader::HEADER_STATUS, int);
    void getStatusVal(ZHeader::HEADER_STATUS);
    void headerSize(ZHeader::HEADER_TYPE);
    void setMeterRange(int, int);
    void setMeterValue(int);
    void showMeter();
    void hideMeter();

  /* 'hidden' slots:
   * slotChangePrimTitle(const QString&)
   * slotChangeSecondTitle(const QString&)
   * slotGetIcon(int)
   * slotDisplayTime()
   * slotPaletteChange()
   * slotLoadDataFromSharedMemory()
   * */

  signals:
    void primTitleChanged(const QString &);
    void secondTitleChanged(const QString &);
    void serverInitialized();

  private:
    char _zheader_stuff[4];
};

#endif
