#ifndef __ZLABEL_H__
#define __ZLABEL_H__

#include <zwidget.h>

class ZWrapLine {
  public:
    enum WrapPolicy {
    };
};

// sizeof == sizeof(ZWidget) + 4
class ZLabel : public ZWidget {
  Q_OBJECT
  public:
    enum MarqueeState {
      None, Standard, Highlighted
    };

    enum MarqueeDirection{
      Left, Right, Top, Bottom
    };

    enum TextDirection{
      LeftToRight, RightToLeft
    };

    // some calls inside libezxappbase set last param to 0x56
    // so i set default value to clsZImageContainer
    // (but clsZLineEdit looks more glamorous)
    ZLabel(QString const &text, QWidget*, char const* = 0, unsigned int = 0,
        ZSkinService::WidgetClsID = ZSkinService::clsZImageContainer);
    ZLabel(QWidget*, char const*, unsigned int,
        ZSkinService::WidgetClsID = ZSkinService::clsZImageContainer);
    virtual ~ZLabel();
    
    virtual void setAlignment(Qt::AlignmentFlags);
    
    // default autoResize (pdata + 0x38 (lsb from 1byte-bitfield ?)) is false
    virtual void setAutoResize(bool);
  
  public slots:
    virtual void setText(QString const&);

  /* 'hidden' slots:
   * clear()
   * slotScrollTimer()
   * */

  public:
    void setFontColor(QColor const&);
    QRect getLabelRect();
    QString text() const;
    
    // constructor sets numLines to 1 (pdata + 0x5c)
    void setNumLines(int);
    
    // current max lines count
    int getRealNums();

    // number of shown lines
    // depends on autoResize (if it false we'll not get more than
    // getRealNums() even if content really holds more lines)
    int getContentNumLines();
  
  protected:
    virtual void setEnabled(bool);
    virtual void setPalette(QPalette const&);
    virtual void resize(int, int);
    virtual void setGeometry(int, int, int, int);
    virtual void setGeometry(QRect const&);
    virtual QSize sizeHint() const;
    virtual int heightForWidth(int) const;
    virtual void paintEvent(QPaintEvent*);
    virtual void showEvent(QShowEvent*);
    virtual void fontChange(QFont const&);
    
    void setLeading(int);
    void getFrameWidth(int&, int&, int&, int&) const;
    void getTrancatestr(QString const&);
    void setMarqueeStep(int);
    void getVTotalHeight();
    void setOutline(bool, QColor, QColor);
    void getLineH(int) const;
    void getSpaceWidth();
    void setMarqueeRepetition(int);
    void getSpacing() const;
    void textDirection() const;
    void setPadding(ZWidgetPaddingInfo const&);
    void setParentBackground(bool);
    void setMarqueeState(ZLabel::MarqueeState);
    void getContentRect();
    void getTruncStr(QString&, char, int);
    void setMarqueeSpeed(int);
    void marqueePlay();
    void setMarqueeDirection(ZLabel::MarqueeDirection);
    void setTextDirection(ZLabel::TextDirection);
    void setPreferredWidth(int);
    void getHTotalWidth();
    void setWrapPolicy(ZWrapLine::WrapPolicy);

  private:
    char _zlabel_stuff[4];
};
#endif
