#ifndef __ZLINEEDIT_H__
#define __ZLINEEDIT_H__

#include <qvalidator.h>
#include <zformitem.h>

// sizeof == 0x138
class ZLineEdit : public ZFormItem {
  Q_OBJECT
  public:
    enum TitlePosition {
      TitleTop, TitleLeft
    };

    enum EchoMode {
      Normal, NoEcho, Password
    };

    enum InsertionMethod {
      Begin, End, Selection
    };

    enum CursorFlagDirection {
	    CF_RTL, CF_LTR
    };

    enum CursorFlagExist {
	    CF_NONE, CF_YES
    };

    enum InputContext {
      IC_NONE, IC_SCROLLING, IC_TEXT_INPUT
    };

    enum InitAutoAlign {
      AlignmentLeft, AlignmentRight
    };

    enum ItemType {
      FormItem, Label, Widget
    };

    enum StateChangeReason {
      RFocusIn, RFocusOut, RKeyPress, RKeyRelease
    };
    
    ZLineEdit(QWidget* = 0, char const* = 0,
        ZSkinService::WidgetClsID = ZSkinService::clsZLineEdit);
    
    // call ZLineEdit::setText(text)
    ZLineEdit(QString const &text, QWidget* = 0, char const* = 0,
        ZSkinService::WidgetClsID = ZSkinService::clsZLineEdit);
    virtual ~ZLineEdit();
    
  protected:
    virtual bool event(QEvent*);
    virtual void setEnabled(bool);
    virtual void setPalette(QPalette const&);
    virtual void setFont(QFont const&);
    virtual QSize sizeHint() const;
    virtual QSize minimumSizeHint() const;
    virtual QSizePolicy sizePolicy() const;
    virtual void mousePressEvent(QMouseEvent*);
    virtual void mouseReleaseEvent(QMouseEvent*);
    virtual void mouseDoubleClickEvent(QMouseEvent*);
    virtual void mouseMoveEvent(QMouseEvent*);
    virtual void keyPressEvent(QKeyEvent*);
    virtual void focusInEvent(QFocusEvent*);
    virtual void focusOutEvent(QFocusEvent*);
    virtual void leaveEvent(QEvent*);
    virtual void paintEvent(QPaintEvent*);
    virtual void resizeEvent(QResizeEvent*);
    virtual void updateSkin(bool);
    
    virtual void setMaxLength(int);
    virtual void setFontPercent(float);
    virtual void setFrame(bool);
    virtual void setEchoMode(ZLineEdit::EchoMode);
    virtual void setValidator(QValidator const*);
    virtual void setSelection(int, int);
    virtual void setCursorPosition(int);
  
  public slots:
    virtual void setText(const QString&);
    void selectAll();
    void insert(const QString&);
    void insertNew(const QString&);
    void clear();
   
  /* 'hidden' slots:
   * deselect()
   * clearValidator()
   * isLTRBidiClass(TsBidiCharClass)
   * isRTRBidiClass(TsBidiCharClass)
   * isNumberBidiClass(TsBidiCharClass)
   * isNeutralBidiClass(TsBidiCharClass)
   * clipboardChanged()
   * blinkSlot()
   * dragScrollSlot()
   * fastDelTimerSlot()
   * */

  public:
    void home(bool);
    bool backspace();
    int cursorPosition() const;
  
  protected:
    void getPaddingHeight() const;
    void getInputField();
    void getEditAreaRect() const;
    void setCursorFlagExist(ZLineEdit::CursorFlagExist);
    void getFrameWidth(int&, int&, int&, int&) const;
    void getInputModeCursorModel();
    void setInsertionMethod(ZLineEdit::InsertionMethod);
    void getContentRect() const;
    void setAlignment(int);
    void setInitAutoAlign(ZLineEdit::InitAutoAlign);
    void getPaddingWidth() const;
    void cursorRightFinish(bool, int);
    void setEchoModeWhenHasFocus(ZLineEdit::EchoMode);
    void edited() const;
    void setTitlePosition(ZLineEdit::TitlePosition);
    void cursorRight(bool);
    void frameW() const;
    void setCursorFlagDirection(ZLineEdit::CursorFlagDirection);
    void stateChanged(ZLineEdit::StateChangeReason);
    void getUnderlineWidth() const;
    void setEchoModeWhenNoFocus(ZLineEdit::EchoMode);
    void getFieldRect() const;
    void phonenoText() const;
    void cursorLeft(bool);
    void setPreferredWidth(int);
    void frame() const;
    void getAlterIconHeight() const;
    void isZEnabled();
    void setEdited(bool);
    void maxLength() const;
    void isReadOnly() const;
    void setReadOnly(bool);
    void setTitle(QString const&);
    void clearValidator();
    void getPreferredWidth() const;
    void getTitleRect() const;
    void text() const;
    void getCurrentFont(QFont&, QColor&, ZLineEdit::ItemType) const;
    void getTitleSize() const;
    void echoMode() const;
    void echoModeNoFocus() const;
    void echoModeHasFocus() const;
    void setAutoResize(bool);
    void validator() const;
    void setMode(ZLineEdit::EchoMode);
    void backspaceNew();
    void getPredefinedNumbers() const;
    
  signals:
    void textChanged(QString const&);
    void commitedTextChanged(const QString &);
    void returnPressed();
    void cursorChanged(int, int);
  
  private:
    char _zlineedit_stuff[0x138 - sizeof(ZFormItem)];
};

#endif
