#ifndef __ZPRESSBUTTON_H__
#define __ZPRESSBUTTON_H__

#include <zbasebutton.h>

// sizeof == 0x11c
class ZPressButton : public ZBaseButton {
  Q_OBJECT
  public:
   
    enum TitlePosition {
      TitleTop, TitleLeft
    };

    ZPressButton(QWidget*, char const*,
        ZSkinService::WidgetClsID = ZSkinService::clsZPressButton);
    ZPressButton(QString const &text, QWidget*, char const*,
        ZSkinService::WidgetClsID = ZSkinService::clsZPressButton);
    ZPressButton(QPixmap const &text, QString const&, QWidget*, char const*,
        ZSkinService::WidgetClsID = ZSkinService::clsZPressButton);
    virtual ~ZPressButton();
  
    virtual void setText(QString const&);
    virtual void setPixmap(QPixmap const&);
    virtual void setToggleButton(bool);
    
    QString text() const;
    QString title() const;
    void setTitle(QString const&);
    void setFontColor(QColor const&);
    bool isZEnabled();
    void setAlignment(Qt::AlignmentFlags);
    TitlePosition titlePosition() const;
  
  public slots:
    virtual void setOn(bool);

  /* 'hidden' slots:
   * toggle()
   * */
  
  protected:
    virtual void setEnabled(bool);
    virtual void setPalette(QPalette const&);
    virtual void setFont(QFont const&);
    virtual QSize sizeHint() const;
    virtual void keyPressEvent(QKeyEvent*);
    virtual void keyReleaseEvent(QKeyEvent*);
    virtual void focusInEvent(QFocusEvent*);
    virtual void focusOutEvent(QFocusEvent*);
    virtual void resizeEvent(QResizeEvent*);
    virtual void updateSkin(bool);
    virtual void drawButton(QPainter*);
    virtual void drawButtonLabel(QPainter*);
  
    QRect getBtnRect() const;
    void getBtnFrameWidth(int&, int&, int&, int&) const;
    void setAvailableWidth(int);
    QRect getBtnContentRect() const;
    QSize getTitleSize() const;
    void getFrameWidth(int&, int&, int&, int&) const;
    QSize getBtnSize() const;
    QRect getContentRect() const;
    void setTitlePosition(ZPressButton::TitlePosition);
    QRect getTitleRect() const;
    void setPixmap_internal(QPixmap const&);

  signals:
    void selectionStateChanged(const SelectionState);

  private:
    char _zpressbutton_stuff[0x11c - sizeof(ZBaseButton)];
};

#endif
