#ifndef __ZSCROLLPANEL_H__
#define __ZSCROLLPANEL_H__

#include <zwidget.h>

class ZScrollBar;

// sizeof == sizeof(ZWidget) + 4
class ZScrollPanel : public ZWidget {
  Q_OBJECT
  public:
    enum ScrollBarMode {
      Auto, AlwaysOff, AlwaysOn
    };

    enum ResizePolicy {
      Default, Manual, AutoOne, AutoOneFit
    };

    ZScrollPanel(QWidget* = 0, char const* = 0, unsigned int = 0,
        ZSkinService::WidgetClsID = ZSkinService::clsZScrollPanel);
    virtual ~ZScrollPanel();
  
  public slots:
    virtual void setEnabled(bool);

  protected: 
    virtual bool eventFilter(QObject*, QEvent*);
    virtual void setPalette(QPalette const&);
    virtual void show();
    virtual void resize(int, int);
    virtual QSize sizeHint() const;
    virtual QSize minimumSizeHint() const;
    virtual QSizePolicy sizePolicy() const;
    virtual void keyPressEvent(QKeyEvent*);
    virtual void resizeEvent(QResizeEvent*);
    virtual void styleChange(QStyle&);
    virtual bool focusNextPrevChild(bool);
    virtual void updateSkin(bool);
    virtual QPixmap *getBgImageForTransparent(bool&);
    virtual void sub_ezxappbase_4198c8ec() {}
    virtual void isScrollPanelTypeWidget() const;
    virtual void sub_ezxappbase_4198c928() {}
    
    virtual void removeChild(ZWidget*);
    virtual void addChild(ZWidget*, int, int);
    virtual void moveChild(ZWidget*, int, int);
    virtual void setVScrollBarMode(ZScrollPanel::ScrollBarMode);
    virtual void setHScrollBarMode(ZScrollPanel::ScrollBarMode);
    virtual void resetFocusItem(bool);
    virtual void getCurrentFocusRect(bool) const;
    virtual void hasNextPrevFocusItem(bool) const;
    virtual void noFocusMode() const;
    virtual void setMargins(int, int, int, int);
    
  protected slots:
    virtual void resizeContents(int, int);
    void scrollBy(int, int);
    virtual void setContentsPos(int, int);
    void ensureVisible(int, int);
    void ensureVisible(int, int, int, int);
    void updateScrollBars();
    void slotContentsResizing(ZScrollPanel*, int, int);

  /* 'hidden' slots:
   * center(int,int)
   * center(int,int,float,float)
   * setEnabled(bool)
   * editCursorMove(bool)
   * hslide(int)
   * vslide(int)
   * slotContentsResizing(ZGroupBox*,int,int)
   * slotContentsResizeTimer()
   * slotContentsResizing(ZMultiLineEdit*,int,int)
   * */
    
  protected:
    virtual void contentsMousePressEvent(QMouseEvent*);
    virtual void contentsMouseReleaseEvent(QMouseEvent*);
    virtual void contentsMouseDoubleClickEvent(QMouseEvent*);
    virtual void contentsMouseMoveEvent(QMouseEvent*);
    virtual void viewportPaintEvent(QPaintEvent*);
    virtual void viewportResizeEvent(QResizeEvent*);
    virtual void viewportMousePressEvent(QMouseEvent*);
    virtual void viewportMouseReleaseEvent(QMouseEvent*);
    virtual void viewportMouseDoubleClickEvent(QMouseEvent*);
    virtual void viewportMouseMoveEvent(QMouseEvent*);
    virtual void drawContentsOffset(QPainter*, int, int, int, int, int, int);
    virtual void drawContents(QPainter*, int, int, int, int);
    virtual void setResizePolicy(ZScrollPanel::ResizePolicy);
    virtual void setHBarGeometry(ZScrollBar&, int, int, int, int);
    virtual void setVBarGeometry(ZScrollBar&, int, int, int, int);
    virtual void insertFormItemChild(ZWidget*, int, int, ZWidget*);
    virtual void drawContents(QPainter*);
    
    void resizePolicy() const;
    void contentsWidth() const;
    void horizontalScrollBar() const;
    void repaintContents(int, int, int, int, bool);
    void childY(ZWidget*);
    void resize(QSize const&);
    void updateContents(int, int, int, int);
    void contentsToViewport(int, int, int&, int&);
    void contentsY() const;
    void contentsHeight() const;
    void topMargin() const;
    void visibleWidth() const;
    void contentsX() const;
    void repaintContents(QRect const&, bool);
    void setZBorder(ZSkinBase::BorderPixmaps&);
    void setZBorder(ZWidgetBorderInfo*);
    void nextChild(ZWidget*) const;
    void setNestScrollPanelMode(bool);
    void viewportToContents(QPoint const&);
    void lastChild() const;
    void rightMargin() const;
    void setAutoExpandInNestMode(bool);
    void visibleHeight() const;
    void viewportSize(int, int) const;
    void setKeyScrollWrap(bool);
    void getLandscapeScroll() const;
    void bottomMargin() const;
    void enableClipper(bool);
    void contentsToViewport(QPoint const&);
    void viewport() const;
    void updateContents(QRect const&);
    void childX(ZWidget*);
    void verticalScrollBar() const;
    void firstChild() const;
    void viewportToContents(int, int, int&, int&);
    void leftMargin() const;

  signals:
    void contentsMoving(int, int);
    void contentsResizing(ZScrollPanel*, int, int);

  private:
    char _zscrollpanel_stuff[4];
};

#endif
